# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btypes.proto\x12\x0bproto_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x91\x02\n\tEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x05\x65xtra\x18\t \x03(\x0b\x32!.proto_types.EventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\rTimingInfoMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x0cNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\x91\x02\n\x08NodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\rnode_relation\x18\n \x01(\x0b\x32\x19.proto_types.NodeRelation\"\xd1\x01\n\x0cRunResultMsg\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\x0btiming_info\x18\x03 \x03(\x0b\x32\x1a.proto_types.TimingInfoMsg\x12\x0e\n\x06thread\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x31\n\x10\x61\x64\x61pter_response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"G\n\x0fReferenceKeyMsg\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\"\\\n\nColumnType\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14previous_column_type\x18\x02 \x01(\t\x12\x1b\n\x13\x63urrent_column_type\x18\x03 \x01(\t\"Y\n\x10\x43olumnConstraint\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x03 \x01(\t\"T\n\x0fModelConstraint\x12\x17\n\x0f\x63onstraint_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\"6\n\x0eGenericMessage\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\"9\n\x11MainReportVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0blog_version\x18\x02 \x01(\x05\"j\n\x14MainReportVersionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.MainReportVersion\"r\n\x0eMainReportArgs\x12\x33\n\x04\x61rgs\x18\x01 \x03(\x0b\x32%.proto_types.MainReportArgs.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x11MainReportArgsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainReportArgs\"+\n\x15MainTrackingUserState\x12\x12\n\nuser_state\x18\x01 \x01(\t\"r\n\x18MainTrackingUserStateMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainTrackingUserState\"5\n\x0fMergedFromState\x12\x12\n\nnum_merged\x18\x01 \x01(\x05\x12\x0e\n\x06sample\x18\x02 \x03(\t\"f\n\x12MergedFromStateMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.MergedFromState\"A\n\x14MissingProfileTarget\x12\x14\n\x0cprofile_name\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\"p\n\x17MissingProfileTargetMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MissingProfileTarget\"(\n\x11InvalidOptionYAML\x12\x13\n\x0boption_name\x18\x01 \x01(\t\"j\n\x14InvalidOptionYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.InvalidOptionYAML\"!\n\x12LogDbtProjectError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"l\n\x15LogDbtProjectErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProjectError\"3\n\x12LogDbtProfileError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08profiles\x18\x02 \x03(\t\"l\n\x15LogDbtProfileErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProfileError\"!\n\x12StarterProjectPath\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"l\n\x15StarterProjectPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StarterProjectPath\"$\n\x15\x43onfigFolderDirectory\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"r\n\x18\x43onfigFolderDirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ConfigFolderDirectory\"\'\n\x14NoSampleProfileFound\x12\x0f\n\x07\x61\x64\x61pter\x18\x01 \x01(\t\"p\n\x17NoSampleProfileFoundMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.NoSampleProfileFound\"6\n\x18ProfileWrittenWithSample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"x\n\x1bProfileWrittenWithSampleMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProfileWrittenWithSample\"B\n$ProfileWrittenWithTargetTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x90\x01\n\'ProfileWrittenWithTargetTemplateYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.ProfileWrittenWithTargetTemplateYAML\"C\n%ProfileWrittenWithProjectTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x92\x01\n(ProfileWrittenWithProjectTemplateYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.ProfileWrittenWithProjectTemplateYAML\"\x12\n\x10SettingUpProfile\"h\n\x13SettingUpProfileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SettingUpProfile\"\x1c\n\x1aInvalidProfileTemplateYAML\"|\n\x1dInvalidProfileTemplateYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.InvalidProfileTemplateYAML\"(\n\x18ProjectNameAlreadyExists\x12\x0c\n\x04name\x18\x01 \x01(\t\"x\n\x1bProjectNameAlreadyExistsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProjectNameAlreadyExists\"K\n\x0eProjectCreated\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x02 \x01(\t\x12\x11\n\tslack_url\x18\x03 \x01(\t\"d\n\x11ProjectCreatedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ProjectCreated\"@\n\x1aPackageRedirectDeprecation\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"|\n\x1dPackageRedirectDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.PackageRedirectDeprecation\"\x1f\n\x1dPackageInstallPathDeprecation\"\x82\x01\n PackageInstallPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.PackageInstallPathDeprecation\"H\n\x1b\x43onfigSourcePathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"~\n\x1e\x43onfigSourcePathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigSourcePathDeprecation\"F\n\x19\x43onfigDataPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"z\n\x1c\x43onfigDataPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.ConfigDataPathDeprecation\"?\n\x19\x41\x64\x61pterDeprecationWarning\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"z\n\x1c\x41\x64\x61pterDeprecationWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.AdapterDeprecationWarning\".\n\x17MetricAttributesRenamed\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\"v\n\x1aMetricAttributesRenamedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.MetricAttributesRenamed\"+\n\x17\x45xposureNameDeprecation\x12\x10\n\x08\x65xposure\x18\x01 \x01(\t\"v\n\x1a\x45xposureNameDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.ExposureNameDeprecation\"^\n\x13InternalDeprecation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x18\n\x10suggested_action\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"n\n\x16InternalDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.InternalDeprecation\"@\n\x1a\x45nvironmentVariableRenamed\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"|\n\x1d\x45nvironmentVariableRenamedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.EnvironmentVariableRenamed\"3\n\x18\x43onfigLogPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"x\n\x1b\x43onfigLogPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ConfigLogPathDeprecation\"6\n\x1b\x43onfigTargetPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"~\n\x1e\x43onfigTargetPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigTargetPathDeprecation\"!\n\x1f\x43ollectFreshnessReturnSignature\"\x86\x01\n\"CollectFreshnessReturnSignatureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.CollectFreshnessReturnSignature\"\x87\x01\n\x11\x41\x64\x61pterEventDebug\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"j\n\x14\x41\x64\x61pterEventDebugMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.AdapterEventDebug\"\x86\x01\n\x10\x41\x64\x61pterEventInfo\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"h\n\x13\x41\x64\x61pterEventInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.AdapterEventInfo\"\x89\x01\n\x13\x41\x64\x61pterEventWarning\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"n\n\x16\x41\x64\x61pterEventWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.AdapterEventWarning\"\x99\x01\n\x11\x41\x64\x61pterEventError\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x10\n\x08\x65xc_info\x18\x05 \x01(\t\"j\n\x14\x41\x64\x61pterEventErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.AdapterEventError\"_\n\rNewConnection\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"b\n\x10NewConnectionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NewConnection\"=\n\x10\x43onnectionReused\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x16\n\x0eorig_conn_name\x18\x02 \x01(\t\"h\n\x13\x43onnectionReusedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConnectionReused\"0\n\x1b\x43onnectionLeftOpenInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"~\n\x1e\x43onnectionLeftOpenInCleanupMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConnectionLeftOpenInCleanup\".\n\x19\x43onnectionClosedInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"z\n\x1c\x43onnectionClosedInCleanupMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.ConnectionClosedInCleanup\"_\n\x0eRollbackFailed\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"d\n\x11RollbackFailedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.RollbackFailed\"O\n\x10\x43onnectionClosed\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"h\n\x13\x43onnectionClosedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConnectionClosed\"Q\n\x12\x43onnectionLeftOpen\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"l\n\x15\x43onnectionLeftOpenMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.ConnectionLeftOpen\"G\n\x08Rollback\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"X\n\x0bRollbackMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.Rollback\"@\n\tCacheMiss\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"Z\n\x0c\x43\x61\x63heMissMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.CacheMiss\"b\n\rListRelations\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12/\n\trelations\x18\x03 \x03(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"b\n\x10ListRelationsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.ListRelations\"`\n\x0e\x43onnectionUsed\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"d\n\x11\x43onnectionUsedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ConnectionUsed\"T\n\x08SQLQuery\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x0b\n\x03sql\x18\x03 \x01(\t\"X\n\x0bSQLQueryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.SQLQuery\"[\n\x0eSQLQueryStatus\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x03 \x01(\x02\"d\n\x11SQLQueryStatusMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.SQLQueryStatus\"H\n\tSQLCommit\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"Z\n\x0cSQLCommitMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.SQLCommit\"a\n\rColTypeChange\x12\x11\n\torig_type\x18\x01 \x01(\t\x12\x10\n\x08new_type\x18\x02 \x01(\t\x12+\n\x05table\x18\x03 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"b\n\x10\x43olTypeChangeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.ColTypeChange\"@\n\x0eSchemaCreation\x12.\n\x08relation\x18\x01 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"d\n\x11SchemaCreationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.SchemaCreation\"<\n\nSchemaDrop\x12.\n\x08relation\x18\x01 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"\\\n\rSchemaDropMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.SchemaDrop\"\xde\x01\n\x0b\x43\x61\x63heAction\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12-\n\x07ref_key\x18\x02 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\x12/\n\tref_key_2\x18\x03 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\x12/\n\tref_key_3\x18\x04 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\x12.\n\x08ref_list\x18\x05 \x03(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"^\n\x0e\x43\x61\x63heActionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.CacheAction\"\x98\x01\n\x0e\x43\x61\x63heDumpGraph\x12\x33\n\x04\x64ump\x18\x01 \x03(\x0b\x32%.proto_types.CacheDumpGraph.DumpEntry\x12\x14\n\x0c\x62\x65\x66ore_after\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x1a+\n\tDumpEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x11\x43\x61\x63heDumpGraphMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CacheDumpGraph\"B\n\x11\x41\x64\x61pterRegistered\x12\x14\n\x0c\x61\x64\x61pter_name\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x61pter_version\x18\x02 \x01(\t\"j\n\x14\x41\x64\x61pterRegisteredMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.AdapterRegistered\"!\n\x12\x41\x64\x61pterImportError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"l\n\x15\x41\x64\x61pterImportErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.AdapterImportError\"#\n\x0fPluginLoadError\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"f\n\x12PluginLoadErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.PluginLoadError\"Z\n\x14NewConnectionOpening\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x18\n\x10\x63onnection_state\x18\x02 \x01(\t\"p\n\x17NewConnectionOpeningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.NewConnectionOpening\"8\n\rCodeExecution\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ode_content\x18\x02 \x01(\t\"b\n\x10\x43odeExecutionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.CodeExecution\"6\n\x13\x43odeExecutionStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x02 \x01(\x02\"n\n\x16\x43odeExecutionStatusMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.CodeExecutionStatus\"%\n\x16\x43\x61talogGenerationError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"t\n\x19\x43\x61talogGenerationErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.CatalogGenerationError\"-\n\x13WriteCatalogFailure\x12\x16\n\x0enum_exceptions\x18\x01 \x01(\x05\"n\n\x16WriteCatalogFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.WriteCatalogFailure\"\x1e\n\x0e\x43\x61talogWritten\x12\x0c\n\x04path\x18\x01 \x01(\t\"d\n\x11\x43\x61talogWrittenMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CatalogWritten\"\x14\n\x12\x43\x61nnotGenerateDocs\"l\n\x15\x43\x61nnotGenerateDocsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.CannotGenerateDocs\"\x11\n\x0f\x42uildingCatalog\"f\n\x12\x42uildingCatalogMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.BuildingCatalog\"-\n\x18\x44\x61tabaseErrorRunningHook\x12\x11\n\thook_type\x18\x01 \x01(\t\"x\n\x1b\x44\x61tabaseErrorRunningHookMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DatabaseErrorRunningHook\"4\n\x0cHooksRunning\x12\x11\n\tnum_hooks\x18\x01 \x01(\x05\x12\x11\n\thook_type\x18\x02 \x01(\t\"`\n\x0fHooksRunningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.HooksRunning\"T\n\x14\x46inishedRunningStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\x12\x11\n\texecution\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x03 \x01(\x02\"p\n\x17\x46inishedRunningStatsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.FinishedRunningStats\"<\n\x15\x43onstraintNotEnforced\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"r\n\x18\x43onstraintNotEnforcedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ConstraintNotEnforced\"=\n\x16\x43onstraintNotSupported\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"t\n\x19\x43onstraintNotSupportedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.ConstraintNotSupported\"7\n\x12InputFileDiffError\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"l\n\x15InputFileDiffErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InputFileDiffError\"?\n\x14InvalidValueForField\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x02 \x01(\t\"p\n\x17InvalidValueForFieldMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.InvalidValueForField\"Q\n\x11ValidationWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\"j\n\x14ValidationWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ValidationWarning\"!\n\x11ParsePerfInfoPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"j\n\x14ParsePerfInfoPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ParsePerfInfoPath\"1\n!PartialParsingErrorProcessingFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\x8a\x01\n$PartialParsingErrorProcessingFileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.PartialParsingErrorProcessingFile\"\x86\x01\n\x13PartialParsingError\x12?\n\x08\x65xc_info\x18\x01 \x03(\x0b\x32-.proto_types.PartialParsingError.ExcInfoEntry\x1a.\n\x0c\x45xcInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x16PartialParsingErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.PartialParsingError\"\x1b\n\x19PartialParsingSkipParsing\"z\n\x1cPartialParsingSkipParsingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.PartialParsingSkipParsing\"&\n\x14UnableToPartialParse\x12\x0e\n\x06reason\x18\x01 \x01(\t\"p\n\x17UnableToPartialParseMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.UnableToPartialParse\"f\n\x12StateCheckVarsHash\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x0c\n\x04vars\x18\x02 \x01(\t\x12\x0f\n\x07profile\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"l\n\x15StateCheckVarsHashMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StateCheckVarsHash\"\x1a\n\x18PartialParsingNotEnabled\"x\n\x1bPartialParsingNotEnabledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.PartialParsingNotEnabled\"C\n\x14ParsedFileLoadFailed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"p\n\x17ParsedFileLoadFailedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParsedFileLoadFailed\"H\n\x15PartialParsingEnabled\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x05\x12\r\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hanged\x18\x03 \x01(\x05\"r\n\x18PartialParsingEnabledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.PartialParsingEnabled\"8\n\x12PartialParsingFile\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\"l\n\x15PartialParsingFileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.PartialParsingFile\"\xaf\x01\n\x1fInvalidDisabledTargetInTestNode\x12\x1b\n\x13resource_type_title\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1a\n\x12original_file_path\x18\x03 \x01(\t\x12\x13\n\x0btarget_kind\x18\x04 \x01(\t\x12\x13\n\x0btarget_name\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\"\x86\x01\n\"InvalidDisabledTargetInTestNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.InvalidDisabledTargetInTestNode\"7\n\x18UnusedResourceConfigPath\x12\x1b\n\x13unused_config_paths\x18\x01 \x03(\t\"x\n\x1bUnusedResourceConfigPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.UnusedResourceConfigPath\"3\n\rSeedIncreased\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x10SeedIncreasedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.SeedIncreased\">\n\x18SeedExceedsLimitSamePath\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n\x1bSeedExceedsLimitSamePathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.SeedExceedsLimitSamePath\"D\n\x1eSeedExceedsLimitAndPathChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x84\x01\n!SeedExceedsLimitAndPathChangedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.SeedExceedsLimitAndPathChanged\"\\\n\x1fSeedExceedsLimitChecksumChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rchecksum_name\x18\x03 \x01(\t\"\x86\x01\n\"SeedExceedsLimitChecksumChangedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.SeedExceedsLimitChecksumChanged\"%\n\x0cUnusedTables\x12\x15\n\runused_tables\x18\x01 \x03(\t\"`\n\x0fUnusedTablesMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.UnusedTables\"\x87\x01\n\x17WrongResourceSchemaFile\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x1c\n\x14plural_resource_type\x18\x03 \x01(\t\x12\x10\n\x08yaml_key\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\"v\n\x1aWrongResourceSchemaFileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.WrongResourceSchemaFile\"K\n\x10NoNodeForYamlKey\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x10\n\x08yaml_key\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"h\n\x13NoNodeForYamlKeyMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.NoNodeForYamlKey\"+\n\x15MacroNotFoundForPatch\x12\x12\n\npatch_name\x18\x01 \x01(\t\"r\n\x18MacroNotFoundForPatchMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MacroNotFoundForPatch\"\xb8\x01\n\x16NodeNotFoundOrDisabled\x12\x1a\n\x12original_file_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_type_title\x18\x03 \x01(\t\x12\x13\n\x0btarget_name\x18\x04 \x01(\t\x12\x13\n\x0btarget_kind\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\x12\x10\n\x08\x64isabled\x18\x07 \x01(\t\"t\n\x19NodeNotFoundOrDisabledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.NodeNotFoundOrDisabled\"H\n\x0fJinjaLogWarning\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"f\n\x12JinjaLogWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.JinjaLogWarning\"E\n\x0cJinjaLogInfo\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"`\n\x0fJinjaLogInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.JinjaLogInfo\"F\n\rJinjaLogDebug\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"b\n\x10JinjaLogDebugMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.JinjaLogDebug\"\xae\x01\n\x1eUnpinnedRefNewVersionAvailable\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rref_node_name\x18\x02 \x01(\t\x12\x18\n\x10ref_node_package\x18\x03 \x01(\t\x12\x18\n\x10ref_node_version\x18\x04 \x01(\t\x12\x17\n\x0fref_max_version\x18\x05 \x01(\t\"\x84\x01\n!UnpinnedRefNewVersionAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.UnpinnedRefNewVersionAvailable\"V\n\x0f\x44\x65precatedModel\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65precation_date\x18\x03 \x01(\t\"f\n\x12\x44\x65precatedModelMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DeprecatedModel\"\xc6\x01\n\x1cUpcomingReferenceDeprecation\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"\x80\x01\n\x1fUpcomingReferenceDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).proto_types.UpcomingReferenceDeprecation\"\xbd\x01\n\x13\x44\x65precatedReference\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"n\n\x16\x44\x65precatedReferenceMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DeprecatedReference\"<\n$UnsupportedConstraintMaterialization\x12\x14\n\x0cmaterialized\x18\x01 \x01(\t\"\x90\x01\n\'UnsupportedConstraintMaterializationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.UnsupportedConstraintMaterialization\"M\n\x14ParseInlineNodeError\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\"p\n\x17ParseInlineNodeErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParseInlineNodeError\"(\n\x19SemanticValidationFailure\x12\x0b\n\x03msg\x18\x02 \x01(\t\"z\n\x1cSemanticValidationFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.SemanticValidationFailure\"\x8a\x03\n\x19UnversionedBreakingChange\x12\x18\n\x10\x62reaking_changes\x18\x01 \x03(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x17\n\x0fmodel_file_path\x18\x03 \x01(\t\x12\"\n\x1a\x63ontract_enforced_disabled\x18\x04 \x01(\x08\x12\x17\n\x0f\x63olumns_removed\x18\x05 \x03(\t\x12\x34\n\x13\x63olumn_type_changes\x18\x06 \x03(\x0b\x32\x17.proto_types.ColumnType\x12I\n\"enforced_column_constraint_removed\x18\x07 \x03(\x0b\x32\x1d.proto_types.ColumnConstraint\x12G\n!enforced_model_constraint_removed\x18\x08 \x03(\x0b\x32\x1c.proto_types.ModelConstraint\x12\x1f\n\x17materialization_changed\x18\t \x03(\t\"z\n\x1cUnversionedBreakingChangeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.UnversionedBreakingChange\"*\n\x14WarnStateTargetEqual\x12\x12\n\nstate_path\x18\x01 \x01(\t\"p\n\x17WarnStateTargetEqualMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.WarnStateTargetEqual\"%\n\x16\x46reshnessConfigProblem\x12\x0b\n\x03msg\x18\x01 \x01(\t\"t\n\x19\x46reshnessConfigProblemMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessConfigProblem\"/\n\x1dGitSparseCheckoutSubdirectory\x12\x0e\n\x06subdir\x18\x01 \x01(\t\"\x82\x01\n GitSparseCheckoutSubdirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.GitSparseCheckoutSubdirectory\"/\n\x1bGitProgressCheckoutRevision\x12\x10\n\x08revision\x18\x01 \x01(\t\"~\n\x1eGitProgressCheckoutRevisionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.GitProgressCheckoutRevision\"4\n%GitProgressUpdatingExistingDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x92\x01\n(GitProgressUpdatingExistingDependencyMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.GitProgressUpdatingExistingDependency\".\n\x1fGitProgressPullingNewDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x86\x01\n\"GitProgressPullingNewDependencyMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressPullingNewDependency\"\x1d\n\x0eGitNothingToDo\x12\x0b\n\x03sha\x18\x01 \x01(\t\"d\n\x11GitNothingToDoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.GitNothingToDo\"E\n\x1fGitProgressUpdatedCheckoutRange\x12\x11\n\tstart_sha\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_sha\x18\x02 \x01(\t\"\x86\x01\n\"GitProgressUpdatedCheckoutRangeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressUpdatedCheckoutRange\"*\n\x17GitProgressCheckedOutAt\x12\x0f\n\x07\x65nd_sha\x18\x01 \x01(\t\"v\n\x1aGitProgressCheckedOutAtMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.GitProgressCheckedOutAt\")\n\x1aRegistryProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"|\n\x1dRegistryProgressGETRequestMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.RegistryProgressGETRequest\"=\n\x1bRegistryProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"~\n\x1eRegistryProgressGETResponseMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RegistryProgressGETResponse\"_\n\x1dSelectorReportInvalidSelector\x12\x17\n\x0fvalid_selectors\x18\x01 \x01(\t\x12\x13\n\x0bspec_method\x18\x02 \x01(\t\x12\x10\n\x08raw_spec\x18\x03 \x01(\t\"\x82\x01\n SelectorReportInvalidSelectorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.SelectorReportInvalidSelector\"\x15\n\x13\x44\x65psNoPackagesFound\"n\n\x16\x44\x65psNoPackagesFoundMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsNoPackagesFound\"/\n\x17\x44\x65psStartPackageInstall\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"v\n\x1a\x44\x65psStartPackageInstallMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsStartPackageInstall\"\'\n\x0f\x44\x65psInstallInfo\x12\x14\n\x0cversion_name\x18\x01 \x01(\t\"f\n\x12\x44\x65psInstallInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DepsInstallInfo\"-\n\x13\x44\x65psUpdateAvailable\x12\x16\n\x0eversion_latest\x18\x01 \x01(\t\"n\n\x16\x44\x65psUpdateAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsUpdateAvailable\"\x0e\n\x0c\x44\x65psUpToDate\"`\n\x0f\x44\x65psUpToDateMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUpToDate\",\n\x14\x44\x65psListSubdirectory\x12\x14\n\x0csubdirectory\x18\x01 \x01(\t\"p\n\x17\x44\x65psListSubdirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.DepsListSubdirectory\".\n\x1a\x44\x65psNotifyUpdatesAvailable\x12\x10\n\x08packages\x18\x01 \x03(\t\"|\n\x1d\x44\x65psNotifyUpdatesAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.DepsNotifyUpdatesAvailable\"1\n\x11RetryExternalCall\x12\x0f\n\x07\x61ttempt\x18\x01 \x01(\x05\x12\x0b\n\x03max\x18\x02 \x01(\x05\"j\n\x14RetryExternalCallMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.RetryExternalCall\"#\n\x14RecordRetryException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"p\n\x17RecordRetryExceptionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.RecordRetryException\".\n\x1fRegistryIndexProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x86\x01\n\"RegistryIndexProgressGETRequestMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryIndexProgressGETRequest\"B\n RegistryIndexProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\x88\x01\n#RegistryIndexProgressGETResponseMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.proto_types.RegistryIndexProgressGETResponse\"2\n\x1eRegistryResponseUnexpectedType\x12\x10\n\x08response\x18\x01 \x01(\t\"\x84\x01\n!RegistryResponseUnexpectedTypeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseUnexpectedType\"2\n\x1eRegistryResponseMissingTopKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x84\x01\n!RegistryResponseMissingTopKeysMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseMissingTopKeys\"5\n!RegistryResponseMissingNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x8a\x01\n$RegistryResponseMissingNestedKeysMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.RegistryResponseMissingNestedKeys\"3\n\x1fRegistryResponseExtraNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x86\x01\n\"RegistryResponseExtraNestedKeysMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryResponseExtraNestedKeys\"(\n\x18\x44\x65psSetDownloadDirectory\x12\x0c\n\x04path\x18\x01 \x01(\t\"x\n\x1b\x44\x65psSetDownloadDirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsSetDownloadDirectory\"-\n\x0c\x44\x65psUnpinned\x12\x10\n\x08revision\x18\x01 \x01(\t\x12\x0b\n\x03git\x18\x02 \x01(\t\"`\n\x0f\x44\x65psUnpinnedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUnpinned\"/\n\x1bNoNodesForSelectionCriteria\x12\x10\n\x08spec_raw\x18\x01 \x01(\t\"~\n\x1eNoNodesForSelectionCriteriaMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.NoNodesForSelectionCriteria\")\n\x10\x44\x65psLockUpdating\x12\x15\n\rlock_filepath\x18\x01 \x01(\t\"h\n\x13\x44\x65psLockUpdatingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.DepsLockUpdating\"R\n\x0e\x44\x65psAddPackage\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x19\n\x11packages_filepath\x18\x03 \x01(\t\"d\n\x11\x44\x65psAddPackageMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DepsAddPackage\"\xa7\x01\n\x19\x44\x65psFoundDuplicatePackage\x12S\n\x0fremoved_package\x18\x01 \x03(\x0b\x32:.proto_types.DepsFoundDuplicatePackage.RemovedPackageEntry\x1a\x35\n\x13RemovedPackageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x1c\x44\x65psFoundDuplicatePackageMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.DepsFoundDuplicatePackage\"$\n\x12\x44\x65psVersionMissing\x12\x0e\n\x06source\x18\x01 \x01(\t\"l\n\x15\x44\x65psVersionMissingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.DepsVersionMissing\"/\n\x17\x44\x65psScrubbedPackageName\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"v\n\x1a\x44\x65psScrubbedPackageNameMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsScrubbedPackageName\"*\n\x1bRunningOperationCaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"~\n\x1eRunningOperationCaughtErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RunningOperationCaughtError\"\x11\n\x0f\x43ompileComplete\"f\n\x12\x43ompileCompleteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.CompileComplete\"\x18\n\x16\x46reshnessCheckComplete\"t\n\x19\x46reshnessCheckCompleteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessCheckComplete\"\x1c\n\nSeedHeader\x12\x0e\n\x06header\x18\x01 \x01(\t\"\\\n\rSeedHeaderMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.SeedHeader\"]\n\x12SQLRunnerException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x02 \x01(\t\x12(\n\tnode_info\x18\x03 \x01(\x0b\x32\x15.proto_types.NodeInfo\"l\n\x15SQLRunnerExceptionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.SQLRunnerException\"\xa8\x01\n\rLogTestResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\x12\n\nnum_models\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"b\n\x10LogTestResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogTestResult\"k\n\x0cLogStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"`\n\x0fLogStartLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.LogStartLine\"\x95\x01\n\x0eLogModelResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"d\n\x11LogModelResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogModelResult\"\x92\x02\n\x11LogSnapshotResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x34\n\x03\x63\x66g\x18\x07 \x03(\x0b\x32\'.proto_types.LogSnapshotResult.CfgEntry\x12\x16\n\x0eresult_message\x18\x08 \x01(\t\x1a*\n\x08\x43\x66gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x14LogSnapshotResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.LogSnapshotResult\"\xb9\x01\n\rLogSeedResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0eresult_message\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x0e\n\x06schema\x18\x07 \x01(\t\x12\x10\n\x08relation\x18\x08 \x01(\t\"b\n\x10LogSeedResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogSeedResult\"\xad\x01\n\x12LogFreshnessResult\x12\x0e\n\x06status\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x13\n\x0bsource_name\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\"l\n\x15LogFreshnessResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogFreshnessResult\"\"\n\rLogCancelLine\x12\x11\n\tconn_name\x18\x01 \x01(\t\"b\n\x10LogCancelLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogCancelLine\"\x1f\n\x0f\x44\x65\x66\x61ultSelector\x12\x0c\n\x04name\x18\x01 \x01(\t\"f\n\x12\x44\x65\x66\x61ultSelectorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DefaultSelector\"5\n\tNodeStart\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"Z\n\x0cNodeStartMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.NodeStart\"g\n\x0cNodeFinished\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12-\n\nrun_result\x18\x02 \x01(\x0b\x32\x19.proto_types.RunResultMsg\"`\n\x0fNodeFinishedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.NodeFinished\"+\n\x1bQueryCancelationUnsupported\x12\x0c\n\x04type\x18\x01 \x01(\t\"~\n\x1eQueryCancelationUnsupportedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.QueryCancelationUnsupported\"O\n\x0f\x43oncurrencyLine\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x05\"f\n\x12\x43oncurrencyLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ConcurrencyLine\"E\n\x19WritingInjectedSQLForNode\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"z\n\x1cWritingInjectedSQLForNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.WritingInjectedSQLForNode\"9\n\rNodeCompiling\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"b\n\x10NodeCompilingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeCompiling\"9\n\rNodeExecuting\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"b\n\x10NodeExecutingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeExecuting\"m\n\x10LogHookStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"h\n\x13LogHookStartLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.LogHookStartLine\"\x93\x01\n\x0eLogHookEndLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"d\n\x11LogHookEndLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogHookEndLine\"\x93\x01\n\x0fSkippingDetails\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tnode_name\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\x12\r\n\x05total\x18\x06 \x01(\x05\"f\n\x12SkippingDetailsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SkippingDetails\"\r\n\x0bNothingToDo\"^\n\x0eNothingToDoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.NothingToDo\",\n\x1dRunningOperationUncaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x82\x01\n RunningOperationUncaughtErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.RunningOperationUncaughtError\"\x93\x01\n\x0c\x45ndRunResult\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.proto_types.RunResultMsg\x12\x14\n\x0c\x65lapsed_time\x18\x02 \x01(\x02\x12\x30\n\x0cgenerated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07success\x18\x04 \x01(\x08\"`\n\x0f\x45ndRunResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.EndRunResult\"\x11\n\x0fNoNodesSelected\"f\n\x12NoNodesSelectedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.NoNodesSelected\"w\n\x10\x43ommandCompleted\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65lapsed\x18\x04 \x01(\x02\"h\n\x13\x43ommandCompletedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.CommandCompleted\"k\n\x08ShowNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07preview\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\"X\n\x0bShowNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.ShowNode\"p\n\x0c\x43ompiledNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ompiled\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\"`\n\x0f\x43ompiledNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.CompiledNode\"b\n\x17\x43\x61tchableExceptionOnRun\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"v\n\x1a\x43\x61tchableExceptionOnRunMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.CatchableExceptionOnRun\"_\n\x12InternalErrorOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12(\n\tnode_info\x18\x03 \x01(\x0b\x32\x15.proto_types.NodeInfo\"l\n\x15InternalErrorOnRunMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InternalErrorOnRun\"u\n\x15GenericExceptionOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\"r\n\x18GenericExceptionOnRunMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.GenericExceptionOnRun\"N\n\x1aNodeConnectionReleaseError\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"|\n\x1dNodeConnectionReleaseErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.NodeConnectionReleaseError\"\x1f\n\nFoundStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\"\\\n\rFoundStatsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.FoundStats\"\x17\n\x15MainKeyboardInterrupt\"r\n\x18MainKeyboardInterruptMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainKeyboardInterrupt\"#\n\x14MainEncounteredError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"p\n\x17MainEncounteredErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MainEncounteredError\"%\n\x0eMainStackTrace\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\"d\n\x11MainStackTraceMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainStackTrace\"@\n\x13SystemCouldNotWrite\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\"n\n\x16SystemCouldNotWriteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.SystemCouldNotWrite\"!\n\x12SystemExecutingCmd\x12\x0b\n\x03\x63md\x18\x01 \x03(\t\"l\n\x15SystemExecutingCmdMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.SystemExecutingCmd\"\x1c\n\x0cSystemStdOut\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"`\n\x0fSystemStdOutMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SystemStdOut\"\x1c\n\x0cSystemStdErr\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"`\n\x0fSystemStdErrMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SystemStdErr\",\n\x16SystemReportReturnCode\x12\x12\n\nreturncode\x18\x01 \x01(\x05\"t\n\x19SystemReportReturnCodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.SystemReportReturnCode\"p\n\x13TimingInfoCollected\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12/\n\x0btiming_info\x18\x02 \x01(\x0b\x32\x1a.proto_types.TimingInfoMsg\"n\n\x16TimingInfoCollectedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.TimingInfoCollected\"&\n\x12LogDebugStackTrace\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"l\n\x15LogDebugStackTraceMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDebugStackTrace\"\x1e\n\x0e\x43heckCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"d\n\x11\x43heckCleanPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CheckCleanPath\" \n\x10\x43onfirmCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"h\n\x13\x43onfirmCleanPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConfirmCleanPath\"\"\n\x12ProtectedCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"l\n\x15ProtectedCleanPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.ProtectedCleanPath\"\x14\n\x12\x46inishedCleanPaths\"l\n\x15\x46inishedCleanPathsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FinishedCleanPaths\"5\n\x0bOpenCommand\x12\x10\n\x08open_cmd\x18\x01 \x01(\t\x12\x14\n\x0cprofiles_dir\x18\x02 \x01(\t\"^\n\x0eOpenCommandMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.OpenCommand\"\x19\n\nFormatting\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\\\n\rFormattingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.Formatting\"0\n\x0fServingDocsPort\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"f\n\x12ServingDocsPortMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ServingDocsPort\"%\n\x15ServingDocsAccessInfo\x12\x0c\n\x04port\x18\x01 \x01(\t\"r\n\x18ServingDocsAccessInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ServingDocsAccessInfo\"\x15\n\x13ServingDocsExitInfo\"n\n\x16ServingDocsExitInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.ServingDocsExitInfo\"J\n\x10RunResultWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"h\n\x13RunResultWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultWarning\"J\n\x10RunResultFailure\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"h\n\x13RunResultFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultFailure\"k\n\tStatsLine\x12\x30\n\x05stats\x18\x01 \x03(\x0b\x32!.proto_types.StatsLine.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"Z\n\x0cStatsLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.StatsLine\"\x1d\n\x0eRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\"d\n\x11RunResultErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.RunResultError\")\n\x17RunResultErrorNoMessage\x12\x0e\n\x06status\x18\x01 \x01(\t\"v\n\x1aRunResultErrorNoMessageMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultErrorNoMessage\"\x1f\n\x0fSQLCompiledPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"f\n\x12SQLCompiledPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SQLCompiledPath\"-\n\x14\x43heckNodeTestFailure\x12\x15\n\rrelation_name\x18\x01 \x01(\t\"p\n\x17\x43heckNodeTestFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.CheckNodeTestFailure\"W\n\x0f\x45ndOfRunSummary\x12\x12\n\nnum_errors\x18\x01 \x01(\x05\x12\x14\n\x0cnum_warnings\x18\x02 \x01(\x05\x12\x1a\n\x12keyboard_interrupt\x18\x03 \x01(\x08\"f\n\x12\x45ndOfRunSummaryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.EndOfRunSummary\"U\n\x13LogSkipBecauseError\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x10\n\x08relation\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"n\n\x16LogSkipBecauseErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.LogSkipBecauseError\"\x14\n\x12\x45nsureGitInstalled\"l\n\x15\x45nsureGitInstalledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.EnsureGitInstalled\"\x1a\n\x18\x44\x65psCreatingLocalSymlink\"x\n\x1b\x44\x65psCreatingLocalSymlinkMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsCreatingLocalSymlink\"\x19\n\x17\x44\x65psSymlinkNotAvailable\"v\n\x1a\x44\x65psSymlinkNotAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsSymlinkNotAvailable\"\x11\n\x0f\x44isableTracking\"f\n\x12\x44isableTrackingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DisableTracking\"\x1e\n\x0cSendingEvent\x12\x0e\n\x06kwargs\x18\x01 \x01(\t\"`\n\x0fSendingEventMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SendingEvent\"\x12\n\x10SendEventFailure\"h\n\x13SendEventFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SendEventFailure\"\r\n\x0b\x46lushEvents\"^\n\x0e\x46lushEventsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.FlushEvents\"\x14\n\x12\x46lushEventsFailure\"l\n\x15\x46lushEventsFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FlushEventsFailure\"-\n\x19TrackingInitializeFailure\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"z\n\x1cTrackingInitializeFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.TrackingInitializeFailure\"&\n\x17RunResultWarningMessage\x12\x0b\n\x03msg\x18\x01 \x01(\t\"v\n\x1aRunResultWarningMessageMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultWarningMessage\"\x1a\n\x0b\x44\x65\x62ugCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"^\n\x0e\x44\x65\x62ugCmdOutMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.DebugCmdOut\"\x1d\n\x0e\x44\x65\x62ugCmdResult\x12\x0b\n\x03msg\x18\x01 \x01(\t\"d\n\x11\x44\x65\x62ugCmdResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DebugCmdResult\"\x19\n\nListCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\\\n\rListCmdOutMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.ListCmdOut\"\x13\n\x04Note\x12\x0b\n\x03msg\x18\x01 \x01(\t\"P\n\x07NoteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x1f\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x11.proto_types.Note\"\xec\x01\n\x0eResourceReport\x12\x14\n\x0c\x63ommand_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ommand_success\x18\x03 \x01(\x08\x12\x1f\n\x17\x63ommand_wall_clock_time\x18\x04 \x01(\x02\x12\x19\n\x11process_user_time\x18\x05 \x01(\x02\x12\x1b\n\x13process_kernel_time\x18\x06 \x01(\x02\x12\x1b\n\x13process_mem_max_rss\x18\x07 \x01(\x03\x12\x19\n\x11process_in_blocks\x18\x08 \x01(\x03\x12\x1a\n\x12process_out_blocks\x18\t \x01(\x03\"d\n\x11ResourceReportMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ResourceReportb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EVENTINFO_EXTRAENTRY._options = None
  _EVENTINFO_EXTRAENTRY._serialized_options = b'8\001'
  _MAINREPORTARGS_ARGSENTRY._options = None
  _MAINREPORTARGS_ARGSENTRY._serialized_options = b'8\001'
  _CACHEDUMPGRAPH_DUMPENTRY._options = None
  _CACHEDUMPGRAPH_DUMPENTRY._serialized_options = b'8\001'
  _PARTIALPARSINGERROR_EXCINFOENTRY._options = None
  _PARTIALPARSINGERROR_EXCINFOENTRY._serialized_options = b'8\001'
  _DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY._options = None
  _DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY._serialized_options = b'8\001'
  _LOGSNAPSHOTRESULT_CFGENTRY._options = None
  _LOGSNAPSHOTRESULT_CFGENTRY._serialized_options = b'8\001'
  _STATSLINE_STATSENTRY._options = None
  _STATSLINE_STATSENTRY._serialized_options = b'8\001'
  _EVENTINFO._serialized_start=92
  _EVENTINFO._serialized_end=365
  _EVENTINFO_EXTRAENTRY._serialized_start=321
  _EVENTINFO_EXTRAENTRY._serialized_end=365
  _TIMINGINFOMSG._serialized_start=367
  _TIMINGINFOMSG._serialized_end=494
  _NODERELATION._serialized_start=496
  _NODERELATION._serialized_end=582
  _NODEINFO._serialized_start=585
  _NODEINFO._serialized_end=858
  _RUNRESULTMSG._serialized_start=861
  _RUNRESULTMSG._serialized_end=1070
  _REFERENCEKEYMSG._serialized_start=1072
  _REFERENCEKEYMSG._serialized_end=1143
  _COLUMNTYPE._serialized_start=1145
  _COLUMNTYPE._serialized_end=1237
  _COLUMNCONSTRAINT._serialized_start=1239
  _COLUMNCONSTRAINT._serialized_end=1328
  _MODELCONSTRAINT._serialized_start=1330
  _MODELCONSTRAINT._serialized_end=1414
  _GENERICMESSAGE._serialized_start=1416
  _GENERICMESSAGE._serialized_end=1470
  _MAINREPORTVERSION._serialized_start=1472
  _MAINREPORTVERSION._serialized_end=1529
  _MAINREPORTVERSIONMSG._serialized_start=1531
  _MAINREPORTVERSIONMSG._serialized_end=1637
  _MAINREPORTARGS._serialized_start=1639
  _MAINREPORTARGS._serialized_end=1753
  _MAINREPORTARGS_ARGSENTRY._serialized_start=1710
  _MAINREPORTARGS_ARGSENTRY._serialized_end=1753
  _MAINREPORTARGSMSG._serialized_start=1755
  _MAINREPORTARGSMSG._serialized_end=1855
  _MAINTRACKINGUSERSTATE._serialized_start=1857
  _MAINTRACKINGUSERSTATE._serialized_end=1900
  _MAINTRACKINGUSERSTATEMSG._serialized_start=1902
  _MAINTRACKINGUSERSTATEMSG._serialized_end=2016
  _MERGEDFROMSTATE._serialized_start=2018
  _MERGEDFROMSTATE._serialized_end=2071
  _MERGEDFROMSTATEMSG._serialized_start=2073
  _MERGEDFROMSTATEMSG._serialized_end=2175
  _MISSINGPROFILETARGET._serialized_start=2177
  _MISSINGPROFILETARGET._serialized_end=2242
  _MISSINGPROFILETARGETMSG._serialized_start=2244
  _MISSINGPROFILETARGETMSG._serialized_end=2356
  _INVALIDOPTIONYAML._serialized_start=2358
  _INVALIDOPTIONYAML._serialized_end=2398
  _INVALIDOPTIONYAMLMSG._serialized_start=2400
  _INVALIDOPTIONYAMLMSG._serialized_end=2506
  _LOGDBTPROJECTERROR._serialized_start=2508
  _LOGDBTPROJECTERROR._serialized_end=2541
  _LOGDBTPROJECTERRORMSG._serialized_start=2543
  _LOGDBTPROJECTERRORMSG._serialized_end=2651
  _LOGDBTPROFILEERROR._serialized_start=2653
  _LOGDBTPROFILEERROR._serialized_end=2704
  _LOGDBTPROFILEERRORMSG._serialized_start=2706
  _LOGDBTPROFILEERRORMSG._serialized_end=2814
  _STARTERPROJECTPATH._serialized_start=2816
  _STARTERPROJECTPATH._serialized_end=2849
  _STARTERPROJECTPATHMSG._serialized_start=2851
  _STARTERPROJECTPATHMSG._serialized_end=2959
  _CONFIGFOLDERDIRECTORY._serialized_start=2961
  _CONFIGFOLDERDIRECTORY._serialized_end=2997
  _CONFIGFOLDERDIRECTORYMSG._serialized_start=2999
  _CONFIGFOLDERDIRECTORYMSG._serialized_end=3113
  _NOSAMPLEPROFILEFOUND._serialized_start=3115
  _NOSAMPLEPROFILEFOUND._serialized_end=3154
  _NOSAMPLEPROFILEFOUNDMSG._serialized_start=3156
  _NOSAMPLEPROFILEFOUNDMSG._serialized_end=3268
  _PROFILEWRITTENWITHSAMPLE._serialized_start=3270
  _PROFILEWRITTENWITHSAMPLE._serialized_end=3324
  _PROFILEWRITTENWITHSAMPLEMSG._serialized_start=3326
  _PROFILEWRITTENWITHSAMPLEMSG._serialized_end=3446
  _PROFILEWRITTENWITHTARGETTEMPLATEYAML._serialized_start=3448
  _PROFILEWRITTENWITHTARGETTEMPLATEYAML._serialized_end=3514
  _PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG._serialized_start=3517
  _PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG._serialized_end=3661
  _PROFILEWRITTENWITHPROJECTTEMPLATEYAML._serialized_start=3663
  _PROFILEWRITTENWITHPROJECTTEMPLATEYAML._serialized_end=3730
  _PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG._serialized_start=3733
  _PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG._serialized_end=3879
  _SETTINGUPPROFILE._serialized_start=3881
  _SETTINGUPPROFILE._serialized_end=3899
  _SETTINGUPPROFILEMSG._serialized_start=3901
  _SETTINGUPPROFILEMSG._serialized_end=4005
  _INVALIDPROFILETEMPLATEYAML._serialized_start=4007
  _INVALIDPROFILETEMPLATEYAML._serialized_end=4035
  _INVALIDPROFILETEMPLATEYAMLMSG._serialized_start=4037
  _INVALIDPROFILETEMPLATEYAMLMSG._serialized_end=4161
  _PROJECTNAMEALREADYEXISTS._serialized_start=4163
  _PROJECTNAMEALREADYEXISTS._serialized_end=4203
  _PROJECTNAMEALREADYEXISTSMSG._serialized_start=4205
  _PROJECTNAMEALREADYEXISTSMSG._serialized_end=4325
  _PROJECTCREATED._serialized_start=4327
  _PROJECTCREATED._serialized_end=4402
  _PROJECTCREATEDMSG._serialized_start=4404
  _PROJECTCREATEDMSG._serialized_end=4504
  _PACKAGEREDIRECTDEPRECATION._serialized_start=4506
  _PACKAGEREDIRECTDEPRECATION._serialized_end=4570
  _PACKAGEREDIRECTDEPRECATIONMSG._serialized_start=4572
  _PACKAGEREDIRECTDEPRECATIONMSG._serialized_end=4696
  _PACKAGEINSTALLPATHDEPRECATION._serialized_start=4698
  _PACKAGEINSTALLPATHDEPRECATION._serialized_end=4729
  _PACKAGEINSTALLPATHDEPRECATIONMSG._serialized_start=4732
  _PACKAGEINSTALLPATHDEPRECATIONMSG._serialized_end=4862
  _CONFIGSOURCEPATHDEPRECATION._serialized_start=4864
  _CONFIGSOURCEPATHDEPRECATION._serialized_end=4936
  _CONFIGSOURCEPATHDEPRECATIONMSG._serialized_start=4938
  _CONFIGSOURCEPATHDEPRECATIONMSG._serialized_end=5064
  _CONFIGDATAPATHDEPRECATION._serialized_start=5066
  _CONFIGDATAPATHDEPRECATION._serialized_end=5136
  _CONFIGDATAPATHDEPRECATIONMSG._serialized_start=5138
  _CONFIGDATAPATHDEPRECATIONMSG._serialized_end=5260
  _ADAPTERDEPRECATIONWARNING._serialized_start=5262
  _ADAPTERDEPRECATIONWARNING._serialized_end=5325
  _ADAPTERDEPRECATIONWARNINGMSG._serialized_start=5327
  _ADAPTERDEPRECATIONWARNINGMSG._serialized_end=5449
  _METRICATTRIBUTESRENAMED._serialized_start=5451
  _METRICATTRIBUTESRENAMED._serialized_end=5497
  _METRICATTRIBUTESRENAMEDMSG._serialized_start=5499
  _METRICATTRIBUTESRENAMEDMSG._serialized_end=5617
  _EXPOSURENAMEDEPRECATION._serialized_start=5619
  _EXPOSURENAMEDEPRECATION._serialized_end=5662
  _EXPOSURENAMEDEPRECATIONMSG._serialized_start=5664
  _EXPOSURENAMEDEPRECATIONMSG._serialized_end=5782
  _INTERNALDEPRECATION._serialized_start=5784
  _INTERNALDEPRECATION._serialized_end=5878
  _INTERNALDEPRECATIONMSG._serialized_start=5880
  _INTERNALDEPRECATIONMSG._serialized_end=5990
  _ENVIRONMENTVARIABLERENAMED._serialized_start=5992
  _ENVIRONMENTVARIABLERENAMED._serialized_end=6056
  _ENVIRONMENTVARIABLERENAMEDMSG._serialized_start=6058
  _ENVIRONMENTVARIABLERENAMEDMSG._serialized_end=6182
  _CONFIGLOGPATHDEPRECATION._serialized_start=6184
  _CONFIGLOGPATHDEPRECATION._serialized_end=6235
  _CONFIGLOGPATHDEPRECATIONMSG._serialized_start=6237
  _CONFIGLOGPATHDEPRECATIONMSG._serialized_end=6357
  _CONFIGTARGETPATHDEPRECATION._serialized_start=6359
  _CONFIGTARGETPATHDEPRECATION._serialized_end=6413
  _CONFIGTARGETPATHDEPRECATIONMSG._serialized_start=6415
  _CONFIGTARGETPATHDEPRECATIONMSG._serialized_end=6541
  _COLLECTFRESHNESSRETURNSIGNATURE._serialized_start=6543
  _COLLECTFRESHNESSRETURNSIGNATURE._serialized_end=6576
  _COLLECTFRESHNESSRETURNSIGNATUREMSG._serialized_start=6579
  _COLLECTFRESHNESSRETURNSIGNATUREMSG._serialized_end=6713
  _ADAPTEREVENTDEBUG._serialized_start=6716
  _ADAPTEREVENTDEBUG._serialized_end=6851
  _ADAPTEREVENTDEBUGMSG._serialized_start=6853
  _ADAPTEREVENTDEBUGMSG._serialized_end=6959
  _ADAPTEREVENTINFO._serialized_start=6962
  _ADAPTEREVENTINFO._serialized_end=7096
  _ADAPTEREVENTINFOMSG._serialized_start=7098
  _ADAPTEREVENTINFOMSG._serialized_end=7202
  _ADAPTEREVENTWARNING._serialized_start=7205
  _ADAPTEREVENTWARNING._serialized_end=7342
  _ADAPTEREVENTWARNINGMSG._serialized_start=7344
  _ADAPTEREVENTWARNINGMSG._serialized_end=7454
  _ADAPTEREVENTERROR._serialized_start=7457
  _ADAPTEREVENTERROR._serialized_end=7610
  _ADAPTEREVENTERRORMSG._serialized_start=7612
  _ADAPTEREVENTERRORMSG._serialized_end=7718
  _NEWCONNECTION._serialized_start=7720
  _NEWCONNECTION._serialized_end=7815
  _NEWCONNECTIONMSG._serialized_start=7817
  _NEWCONNECTIONMSG._serialized_end=7915
  _CONNECTIONREUSED._serialized_start=7917
  _CONNECTIONREUSED._serialized_end=7978
  _CONNECTIONREUSEDMSG._serialized_start=7980
  _CONNECTIONREUSEDMSG._serialized_end=8084
  _CONNECTIONLEFTOPENINCLEANUP._serialized_start=8086
  _CONNECTIONLEFTOPENINCLEANUP._serialized_end=8134
  _CONNECTIONLEFTOPENINCLEANUPMSG._serialized_start=8136
  _CONNECTIONLEFTOPENINCLEANUPMSG._serialized_end=8262
  _CONNECTIONCLOSEDINCLEANUP._serialized_start=8264
  _CONNECTIONCLOSEDINCLEANUP._serialized_end=8310
  _CONNECTIONCLOSEDINCLEANUPMSG._serialized_start=8312
  _CONNECTIONCLOSEDINCLEANUPMSG._serialized_end=8434
  _ROLLBACKFAILED._serialized_start=8436
  _ROLLBACKFAILED._serialized_end=8531
  _ROLLBACKFAILEDMSG._serialized_start=8533
  _ROLLBACKFAILEDMSG._serialized_end=8633
  _CONNECTIONCLOSED._serialized_start=8635
  _CONNECTIONCLOSED._serialized_end=8714
  _CONNECTIONCLOSEDMSG._serialized_start=8716
  _CONNECTIONCLOSEDMSG._serialized_end=8820
  _CONNECTIONLEFTOPEN._serialized_start=8822
  _CONNECTIONLEFTOPEN._serialized_end=8903
  _CONNECTIONLEFTOPENMSG._serialized_start=8905
  _CONNECTIONLEFTOPENMSG._serialized_end=9013
  _ROLLBACK._serialized_start=9015
  _ROLLBACK._serialized_end=9086
  _ROLLBACKMSG._serialized_start=9088
  _ROLLBACKMSG._serialized_end=9176
  _CACHEMISS._serialized_start=9178
  _CACHEMISS._serialized_end=9242
  _CACHEMISSMSG._serialized_start=9244
  _CACHEMISSMSG._serialized_end=9334
  _LISTRELATIONS._serialized_start=9336
  _LISTRELATIONS._serialized_end=9434
  _LISTRELATIONSMSG._serialized_start=9436
  _LISTRELATIONSMSG._serialized_end=9534
  _CONNECTIONUSED._serialized_start=9536
  _CONNECTIONUSED._serialized_end=9632
  _CONNECTIONUSEDMSG._serialized_start=9634
  _CONNECTIONUSEDMSG._serialized_end=9734
  _SQLQUERY._serialized_start=9736
  _SQLQUERY._serialized_end=9820
  _SQLQUERYMSG._serialized_start=9822
  _SQLQUERYMSG._serialized_end=9910
  _SQLQUERYSTATUS._serialized_start=9912
  _SQLQUERYSTATUS._serialized_end=10003
  _SQLQUERYSTATUSMSG._serialized_start=10005
  _SQLQUERYSTATUSMSG._serialized_end=10105
  _SQLCOMMIT._serialized_start=10107
  _SQLCOMMIT._serialized_end=10179
  _SQLCOMMITMSG._serialized_start=10181
  _SQLCOMMITMSG._serialized_end=10271
  _COLTYPECHANGE._serialized_start=10273
  _COLTYPECHANGE._serialized_end=10370
  _COLTYPECHANGEMSG._serialized_start=10372
  _COLTYPECHANGEMSG._serialized_end=10470
  _SCHEMACREATION._serialized_start=10472
  _SCHEMACREATION._serialized_end=10536
  _SCHEMACREATIONMSG._serialized_start=10538
  _SCHEMACREATIONMSG._serialized_end=10638
  _SCHEMADROP._serialized_start=10640
  _SCHEMADROP._serialized_end=10700
  _SCHEMADROPMSG._serialized_start=10702
  _SCHEMADROPMSG._serialized_end=10794
  _CACHEACTION._serialized_start=10797
  _CACHEACTION._serialized_end=11019
  _CACHEACTIONMSG._serialized_start=11021
  _CACHEACTIONMSG._serialized_end=11115
  _CACHEDUMPGRAPH._serialized_start=11118
  _CACHEDUMPGRAPH._serialized_end=11270
  _CACHEDUMPGRAPH_DUMPENTRY._serialized_start=11227
  _CACHEDUMPGRAPH_DUMPENTRY._serialized_end=11270
  _CACHEDUMPGRAPHMSG._serialized_start=11272
  _CACHEDUMPGRAPHMSG._serialized_end=11372
  _ADAPTERREGISTERED._serialized_start=11374
  _ADAPTERREGISTERED._serialized_end=11440
  _ADAPTERREGISTEREDMSG._serialized_start=11442
  _ADAPTERREGISTEREDMSG._serialized_end=11548
  _ADAPTERIMPORTERROR._serialized_start=11550
  _ADAPTERIMPORTERROR._serialized_end=11583
  _ADAPTERIMPORTERRORMSG._serialized_start=11585
  _ADAPTERIMPORTERRORMSG._serialized_end=11693
  _PLUGINLOADERROR._serialized_start=11695
  _PLUGINLOADERROR._serialized_end=11730
  _PLUGINLOADERRORMSG._serialized_start=11732
  _PLUGINLOADERRORMSG._serialized_end=11834
  _NEWCONNECTIONOPENING._serialized_start=11836
  _NEWCONNECTIONOPENING._serialized_end=11926
  _NEWCONNECTIONOPENINGMSG._serialized_start=11928
  _NEWCONNECTIONOPENINGMSG._serialized_end=12040
  _CODEEXECUTION._serialized_start=12042
  _CODEEXECUTION._serialized_end=12098
  _CODEEXECUTIONMSG._serialized_start=12100
  _CODEEXECUTIONMSG._serialized_end=12198
  _CODEEXECUTIONSTATUS._serialized_start=12200
  _CODEEXECUTIONSTATUS._serialized_end=12254
  _CODEEXECUTIONSTATUSMSG._serialized_start=12256
  _CODEEXECUTIONSTATUSMSG._serialized_end=12366
  _CATALOGGENERATIONERROR._serialized_start=12368
  _CATALOGGENERATIONERROR._serialized_end=12405
  _CATALOGGENERATIONERRORMSG._serialized_start=12407
  _CATALOGGENERATIONERRORMSG._serialized_end=12523
  _WRITECATALOGFAILURE._serialized_start=12525
  _WRITECATALOGFAILURE._serialized_end=12570
  _WRITECATALOGFAILUREMSG._serialized_start=12572
  _WRITECATALOGFAILUREMSG._serialized_end=12682
  _CATALOGWRITTEN._serialized_start=12684
  _CATALOGWRITTEN._serialized_end=12714
  _CATALOGWRITTENMSG._serialized_start=12716
  _CATALOGWRITTENMSG._serialized_end=12816
  _CANNOTGENERATEDOCS._serialized_start=12818
  _CANNOTGENERATEDOCS._serialized_end=12838
  _CANNOTGENERATEDOCSMSG._serialized_start=12840
  _CANNOTGENERATEDOCSMSG._serialized_end=12948
  _BUILDINGCATALOG._serialized_start=12950
  _BUILDINGCATALOG._serialized_end=12967
  _BUILDINGCATALOGMSG._serialized_start=12969
  _BUILDINGCATALOGMSG._serialized_end=13071
  _DATABASEERRORRUNNINGHOOK._serialized_start=13073
  _DATABASEERRORRUNNINGHOOK._serialized_end=13118
  _DATABASEERRORRUNNINGHOOKMSG._serialized_start=13120
  _DATABASEERRORRUNNINGHOOKMSG._serialized_end=13240
  _HOOKSRUNNING._serialized_start=13242
  _HOOKSRUNNING._serialized_end=13294
  _HOOKSRUNNINGMSG._serialized_start=13296
  _HOOKSRUNNINGMSG._serialized_end=13392
  _FINISHEDRUNNINGSTATS._serialized_start=13394
  _FINISHEDRUNNINGSTATS._serialized_end=13478
  _FINISHEDRUNNINGSTATSMSG._serialized_start=13480
  _FINISHEDRUNNINGSTATSMSG._serialized_end=13592
  _CONSTRAINTNOTENFORCED._serialized_start=13594
  _CONSTRAINTNOTENFORCED._serialized_end=13654
  _CONSTRAINTNOTENFORCEDMSG._serialized_start=13656
  _CONSTRAINTNOTENFORCEDMSG._serialized_end=13770
  _CONSTRAINTNOTSUPPORTED._serialized_start=13772
  _CONSTRAINTNOTSUPPORTED._serialized_end=13833
  _CONSTRAINTNOTSUPPORTEDMSG._serialized_start=13835
  _CONSTRAINTNOTSUPPORTEDMSG._serialized_end=13951
  _INPUTFILEDIFFERROR._serialized_start=13953
  _INPUTFILEDIFFERROR._serialized_end=14008
  _INPUTFILEDIFFERRORMSG._serialized_start=14010
  _INPUTFILEDIFFERRORMSG._serialized_end=14118
  _INVALIDVALUEFORFIELD._serialized_start=14120
  _INVALIDVALUEFORFIELD._serialized_end=14183
  _INVALIDVALUEFORFIELDMSG._serialized_start=14185
  _INVALIDVALUEFORFIELDMSG._serialized_end=14297
  _VALIDATIONWARNING._serialized_start=14299
  _VALIDATIONWARNING._serialized_end=14380
  _VALIDATIONWARNINGMSG._serialized_start=14382
  _VALIDATIONWARNINGMSG._serialized_end=14488
  _PARSEPERFINFOPATH._serialized_start=14490
  _PARSEPERFINFOPATH._serialized_end=14523
  _PARSEPERFINFOPATHMSG._serialized_start=14525
  _PARSEPERFINFOPATHMSG._serialized_end=14631
  _PARTIALPARSINGERRORPROCESSINGFILE._serialized_start=14633
  _PARTIALPARSINGERRORPROCESSINGFILE._serialized_end=14682
  _PARTIALPARSINGERRORPROCESSINGFILEMSG._serialized_start=14685
  _PARTIALPARSINGERRORPROCESSINGFILEMSG._serialized_end=14823
  _PARTIALPARSINGERROR._serialized_start=14826
  _PARTIALPARSINGERROR._serialized_end=14960
  _PARTIALPARSINGERROR_EXCINFOENTRY._serialized_start=14914
  _PARTIALPARSINGERROR_EXCINFOENTRY._serialized_end=14960
  _PARTIALPARSINGERRORMSG._serialized_start=14962
  _PARTIALPARSINGERRORMSG._serialized_end=15072
  _PARTIALPARSINGSKIPPARSING._serialized_start=15074
  _PARTIALPARSINGSKIPPARSING._serialized_end=15101
  _PARTIALPARSINGSKIPPARSINGMSG._serialized_start=15103
  _PARTIALPARSINGSKIPPARSINGMSG._serialized_end=15225
  _UNABLETOPARTIALPARSE._serialized_start=15227
  _UNABLETOPARTIALPARSE._serialized_end=15265
  _UNABLETOPARTIALPARSEMSG._serialized_start=15267
  _UNABLETOPARTIALPARSEMSG._serialized_end=15379
  _STATECHECKVARSHASH._serialized_start=15381
  _STATECHECKVARSHASH._serialized_end=15483
  _STATECHECKVARSHASHMSG._serialized_start=15485
  _STATECHECKVARSHASHMSG._serialized_end=15593
  _PARTIALPARSINGNOTENABLED._serialized_start=15595
  _PARTIALPARSINGNOTENABLED._serialized_end=15621
  _PARTIALPARSINGNOTENABLEDMSG._serialized_start=15623
  _PARTIALPARSINGNOTENABLEDMSG._serialized_end=15743
  _PARSEDFILELOADFAILED._serialized_start=15745
  _PARSEDFILELOADFAILED._serialized_end=15812
  _PARSEDFILELOADFAILEDMSG._serialized_start=15814
  _PARSEDFILELOADFAILEDMSG._serialized_end=15926
  _PARTIALPARSINGENABLED._serialized_start=15928
  _PARTIALPARSINGENABLED._serialized_end=16000
  _PARTIALPARSINGENABLEDMSG._serialized_start=16002
  _PARTIALPARSINGENABLEDMSG._serialized_end=16116
  _PARTIALPARSINGFILE._serialized_start=16118
  _PARTIALPARSINGFILE._serialized_end=16174
  _PARTIALPARSINGFILEMSG._serialized_start=16176
  _PARTIALPARSINGFILEMSG._serialized_end=16284
  _INVALIDDISABLEDTARGETINTESTNODE._serialized_start=16287
  _INVALIDDISABLEDTARGETINTESTNODE._serialized_end=16462
  _INVALIDDISABLEDTARGETINTESTNODEMSG._serialized_start=16465
  _INVALIDDISABLEDTARGETINTESTNODEMSG._serialized_end=16599
  _UNUSEDRESOURCECONFIGPATH._serialized_start=16601
  _UNUSEDRESOURCECONFIGPATH._serialized_end=16656
  _UNUSEDRESOURCECONFIGPATHMSG._serialized_start=16658
  _UNUSEDRESOURCECONFIGPATHMSG._serialized_end=16778
  _SEEDINCREASED._serialized_start=16780
  _SEEDINCREASED._serialized_end=16831
  _SEEDINCREASEDMSG._serialized_start=16833
  _SEEDINCREASEDMSG._serialized_end=16931
  _SEEDEXCEEDSLIMITSAMEPATH._serialized_start=16933
  _SEEDEXCEEDSLIMITSAMEPATH._serialized_end=16995
  _SEEDEXCEEDSLIMITSAMEPATHMSG._serialized_start=16997
  _SEEDEXCEEDSLIMITSAMEPATHMSG._serialized_end=17117
  _SEEDEXCEEDSLIMITANDPATHCHANGED._serialized_start=17119
  _SEEDEXCEEDSLIMITANDPATHCHANGED._serialized_end=17187
  _SEEDEXCEEDSLIMITANDPATHCHANGEDMSG._serialized_start=17190
  _SEEDEXCEEDSLIMITANDPATHCHANGEDMSG._serialized_end=17322
  _SEEDEXCEEDSLIMITCHECKSUMCHANGED._serialized_start=17324
  _SEEDEXCEEDSLIMITCHECKSUMCHANGED._serialized_end=17416
  _SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG._serialized_start=17419
  _SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG._serialized_end=17553
  _UNUSEDTABLES._serialized_start=17555
  _UNUSEDTABLES._serialized_end=17592
  _UNUSEDTABLESMSG._serialized_start=17594
  _UNUSEDTABLESMSG._serialized_end=17690
  _WRONGRESOURCESCHEMAFILE._serialized_start=17693
  _WRONGRESOURCESCHEMAFILE._serialized_end=17828
  _WRONGRESOURCESCHEMAFILEMSG._serialized_start=17830
  _WRONGRESOURCESCHEMAFILEMSG._serialized_end=17948
  _NONODEFORYAMLKEY._serialized_start=17950
  _NONODEFORYAMLKEY._serialized_end=18025
  _NONODEFORYAMLKEYMSG._serialized_start=18027
  _NONODEFORYAMLKEYMSG._serialized_end=18131
  _MACRONOTFOUNDFORPATCH._serialized_start=18133
  _MACRONOTFOUNDFORPATCH._serialized_end=18176
  _MACRONOTFOUNDFORPATCHMSG._serialized_start=18178
  _MACRONOTFOUNDFORPATCHMSG._serialized_end=18292
  _NODENOTFOUNDORDISABLED._serialized_start=18295
  _NODENOTFOUNDORDISABLED._serialized_end=18479
  _NODENOTFOUNDORDISABLEDMSG._serialized_start=18481
  _NODENOTFOUNDORDISABLEDMSG._serialized_end=18597
  _JINJALOGWARNING._serialized_start=18599
  _JINJALOGWARNING._serialized_end=18671
  _JINJALOGWARNINGMSG._serialized_start=18673
  _JINJALOGWARNINGMSG._serialized_end=18775
  _JINJALOGINFO._serialized_start=18777
  _JINJALOGINFO._serialized_end=18846
  _JINJALOGINFOMSG._serialized_start=18848
  _JINJALOGINFOMSG._serialized_end=18944
  _JINJALOGDEBUG._serialized_start=18946
  _JINJALOGDEBUG._serialized_end=19016
  _JINJALOGDEBUGMSG._serialized_start=19018
  _JINJALOGDEBUGMSG._serialized_end=19116
  _UNPINNEDREFNEWVERSIONAVAILABLE._serialized_start=19119
  _UNPINNEDREFNEWVERSIONAVAILABLE._serialized_end=19293
  _UNPINNEDREFNEWVERSIONAVAILABLEMSG._serialized_start=19296
  _UNPINNEDREFNEWVERSIONAVAILABLEMSG._serialized_end=19428
  _DEPRECATEDMODEL._serialized_start=19430
  _DEPRECATEDMODEL._serialized_end=19516
  _DEPRECATEDMODELMSG._serialized_start=19518
  _DEPRECATEDMODELMSG._serialized_end=19620
  _UPCOMINGREFERENCEDEPRECATION._serialized_start=19623
  _UPCOMINGREFERENCEDEPRECATION._serialized_end=19821
  _UPCOMINGREFERENCEDEPRECATIONMSG._serialized_start=19824
  _UPCOMINGREFERENCEDEPRECATIONMSG._serialized_end=19952
  _DEPRECATEDREFERENCE._serialized_start=19955
  _DEPRECATEDREFERENCE._serialized_end=20144
  _DEPRECATEDREFERENCEMSG._serialized_start=20146
  _DEPRECATEDREFERENCEMSG._serialized_end=20256
  _UNSUPPORTEDCONSTRAINTMATERIALIZATION._serialized_start=20258
  _UNSUPPORTEDCONSTRAINTMATERIALIZATION._serialized_end=20318
  _UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG._serialized_start=20321
  _UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG._serialized_end=20465
  _PARSEINLINENODEERROR._serialized_start=20467
  _PARSEINLINENODEERROR._serialized_end=20544
  _PARSEINLINENODEERRORMSG._serialized_start=20546
  _PARSEINLINENODEERRORMSG._serialized_end=20658
  _SEMANTICVALIDATIONFAILURE._serialized_start=20660
  _SEMANTICVALIDATIONFAILURE._serialized_end=20700
  _SEMANTICVALIDATIONFAILUREMSG._serialized_start=20702
  _SEMANTICVALIDATIONFAILUREMSG._serialized_end=20824
  _UNVERSIONEDBREAKINGCHANGE._serialized_start=20827
  _UNVERSIONEDBREAKINGCHANGE._serialized_end=21221
  _UNVERSIONEDBREAKINGCHANGEMSG._serialized_start=21223
  _UNVERSIONEDBREAKINGCHANGEMSG._serialized_end=21345
  _WARNSTATETARGETEQUAL._serialized_start=21347
  _WARNSTATETARGETEQUAL._serialized_end=21389
  _WARNSTATETARGETEQUALMSG._serialized_start=21391
  _WARNSTATETARGETEQUALMSG._serialized_end=21503
  _FRESHNESSCONFIGPROBLEM._serialized_start=21505
  _FRESHNESSCONFIGPROBLEM._serialized_end=21542
  _FRESHNESSCONFIGPROBLEMMSG._serialized_start=21544
  _FRESHNESSCONFIGPROBLEMMSG._serialized_end=21660
  _GITSPARSECHECKOUTSUBDIRECTORY._serialized_start=21662
  _GITSPARSECHECKOUTSUBDIRECTORY._serialized_end=21709
  _GITSPARSECHECKOUTSUBDIRECTORYMSG._serialized_start=21712
  _GITSPARSECHECKOUTSUBDIRECTORYMSG._serialized_end=21842
  _GITPROGRESSCHECKOUTREVISION._serialized_start=21844
  _GITPROGRESSCHECKOUTREVISION._serialized_end=21891
  _GITPROGRESSCHECKOUTREVISIONMSG._serialized_start=21893
  _GITPROGRESSCHECKOUTREVISIONMSG._serialized_end=22019
  _GITPROGRESSUPDATINGEXISTINGDEPENDENCY._serialized_start=22021
  _GITPROGRESSUPDATINGEXISTINGDEPENDENCY._serialized_end=22073
  _GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG._serialized_start=22076
  _GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG._serialized_end=22222
  _GITPROGRESSPULLINGNEWDEPENDENCY._serialized_start=22224
  _GITPROGRESSPULLINGNEWDEPENDENCY._serialized_end=22270
  _GITPROGRESSPULLINGNEWDEPENDENCYMSG._serialized_start=22273
  _GITPROGRESSPULLINGNEWDEPENDENCYMSG._serialized_end=22407
  _GITNOTHINGTODO._serialized_start=22409
  _GITNOTHINGTODO._serialized_end=22438
  _GITNOTHINGTODOMSG._serialized_start=22440
  _GITNOTHINGTODOMSG._serialized_end=22540
  _GITPROGRESSUPDATEDCHECKOUTRANGE._serialized_start=22542
  _GITPROGRESSUPDATEDCHECKOUTRANGE._serialized_end=22611
  _GITPROGRESSUPDATEDCHECKOUTRANGEMSG._serialized_start=22614
  _GITPROGRESSUPDATEDCHECKOUTRANGEMSG._serialized_end=22748
  _GITPROGRESSCHECKEDOUTAT._serialized_start=22750
  _GITPROGRESSCHECKEDOUTAT._serialized_end=22792
  _GITPROGRESSCHECKEDOUTATMSG._serialized_start=22794
  _GITPROGRESSCHECKEDOUTATMSG._serialized_end=22912
  _REGISTRYPROGRESSGETREQUEST._serialized_start=22914
  _REGISTRYPROGRESSGETREQUEST._serialized_end=22955
  _REGISTRYPROGRESSGETREQUESTMSG._serialized_start=22957
  _REGISTRYPROGRESSGETREQUESTMSG._serialized_end=23081
  _REGISTRYPROGRESSGETRESPONSE._serialized_start=23083
  _REGISTRYPROGRESSGETRESPONSE._serialized_end=23144
  _REGISTRYPROGRESSGETRESPONSEMSG._serialized_start=23146
  _REGISTRYPROGRESSGETRESPONSEMSG._serialized_end=23272
  _SELECTORREPORTINVALIDSELECTOR._serialized_start=23274
  _SELECTORREPORTINVALIDSELECTOR._serialized_end=23369
  _SELECTORREPORTINVALIDSELECTORMSG._serialized_start=23372
  _SELECTORREPORTINVALIDSELECTORMSG._serialized_end=23502
  _DEPSNOPACKAGESFOUND._serialized_start=23504
  _DEPSNOPACKAGESFOUND._serialized_end=23525
  _DEPSNOPACKAGESFOUNDMSG._serialized_start=23527
  _DEPSNOPACKAGESFOUNDMSG._serialized_end=23637
  _DEPSSTARTPACKAGEINSTALL._serialized_start=23639
  _DEPSSTARTPACKAGEINSTALL._serialized_end=23686
  _DEPSSTARTPACKAGEINSTALLMSG._serialized_start=23688
  _DEPSSTARTPACKAGEINSTALLMSG._serialized_end=23806
  _DEPSINSTALLINFO._serialized_start=23808
  _DEPSINSTALLINFO._serialized_end=23847
  _DEPSINSTALLINFOMSG._serialized_start=23849
  _DEPSINSTALLINFOMSG._serialized_end=23951
  _DEPSUPDATEAVAILABLE._serialized_start=23953
  _DEPSUPDATEAVAILABLE._serialized_end=23998
  _DEPSUPDATEAVAILABLEMSG._serialized_start=24000
  _DEPSUPDATEAVAILABLEMSG._serialized_end=24110
  _DEPSUPTODATE._serialized_start=24112
  _DEPSUPTODATE._serialized_end=24126
  _DEPSUPTODATEMSG._serialized_start=24128
  _DEPSUPTODATEMSG._serialized_end=24224
  _DEPSLISTSUBDIRECTORY._serialized_start=24226
  _DEPSLISTSUBDIRECTORY._serialized_end=24270
  _DEPSLISTSUBDIRECTORYMSG._serialized_start=24272
  _DEPSLISTSUBDIRECTORYMSG._serialized_end=24384
  _DEPSNOTIFYUPDATESAVAILABLE._serialized_start=24386
  _DEPSNOTIFYUPDATESAVAILABLE._serialized_end=24432
  _DEPSNOTIFYUPDATESAVAILABLEMSG._serialized_start=24434
  _DEPSNOTIFYUPDATESAVAILABLEMSG._serialized_end=24558
  _RETRYEXTERNALCALL._serialized_start=24560
  _RETRYEXTERNALCALL._serialized_end=24609
  _RETRYEXTERNALCALLMSG._serialized_start=24611
  _RETRYEXTERNALCALLMSG._serialized_end=24717
  _RECORDRETRYEXCEPTION._serialized_start=24719
  _RECORDRETRYEXCEPTION._serialized_end=24754
  _RECORDRETRYEXCEPTIONMSG._serialized_start=24756
  _RECORDRETRYEXCEPTIONMSG._serialized_end=24868
  _REGISTRYINDEXPROGRESSGETREQUEST._serialized_start=24870
  _REGISTRYINDEXPROGRESSGETREQUEST._serialized_end=24916
  _REGISTRYINDEXPROGRESSGETREQUESTMSG._serialized_start=24919
  _REGISTRYINDEXPROGRESSGETREQUESTMSG._serialized_end=25053
  _REGISTRYINDEXPROGRESSGETRESPONSE._serialized_start=25055
  _REGISTRYINDEXPROGRESSGETRESPONSE._serialized_end=25121
  _REGISTRYINDEXPROGRESSGETRESPONSEMSG._serialized_start=25124
  _REGISTRYINDEXPROGRESSGETRESPONSEMSG._serialized_end=25260
  _REGISTRYRESPONSEUNEXPECTEDTYPE._serialized_start=25262
  _REGISTRYRESPONSEUNEXPECTEDTYPE._serialized_end=25312
  _REGISTRYRESPONSEUNEXPECTEDTYPEMSG._serialized_start=25315
  _REGISTRYRESPONSEUNEXPECTEDTYPEMSG._serialized_end=25447
  _REGISTRYRESPONSEMISSINGTOPKEYS._serialized_start=25449
  _REGISTRYRESPONSEMISSINGTOPKEYS._serialized_end=25499
  _REGISTRYRESPONSEMISSINGTOPKEYSMSG._serialized_start=25502
  _REGISTRYRESPONSEMISSINGTOPKEYSMSG._serialized_end=25634
  _REGISTRYRESPONSEMISSINGNESTEDKEYS._serialized_start=25636
  _REGISTRYRESPONSEMISSINGNESTEDKEYS._serialized_end=25689
  _REGISTRYRESPONSEMISSINGNESTEDKEYSMSG._serialized_start=25692
  _REGISTRYRESPONSEMISSINGNESTEDKEYSMSG._serialized_end=25830
  _REGISTRYRESPONSEEXTRANESTEDKEYS._serialized_start=25832
  _REGISTRYRESPONSEEXTRANESTEDKEYS._serialized_end=25883
  _REGISTRYRESPONSEEXTRANESTEDKEYSMSG._serialized_start=25886
  _REGISTRYRESPONSEEXTRANESTEDKEYSMSG._serialized_end=26020
  _DEPSSETDOWNLOADDIRECTORY._serialized_start=26022
  _DEPSSETDOWNLOADDIRECTORY._serialized_end=26062
  _DEPSSETDOWNLOADDIRECTORYMSG._serialized_start=26064
  _DEPSSETDOWNLOADDIRECTORYMSG._serialized_end=26184
  _DEPSUNPINNED._serialized_start=26186
  _DEPSUNPINNED._serialized_end=26231
  _DEPSUNPINNEDMSG._serialized_start=26233
  _DEPSUNPINNEDMSG._serialized_end=26329
  _NONODESFORSELECTIONCRITERIA._serialized_start=26331
  _NONODESFORSELECTIONCRITERIA._serialized_end=26378
  _NONODESFORSELECTIONCRITERIAMSG._serialized_start=26380
  _NONODESFORSELECTIONCRITERIAMSG._serialized_end=26506
  _DEPSLOCKUPDATING._serialized_start=26508
  _DEPSLOCKUPDATING._serialized_end=26549
  _DEPSLOCKUPDATINGMSG._serialized_start=26551
  _DEPSLOCKUPDATINGMSG._serialized_end=26655
  _DEPSADDPACKAGE._serialized_start=26657
  _DEPSADDPACKAGE._serialized_end=26739
  _DEPSADDPACKAGEMSG._serialized_start=26741
  _DEPSADDPACKAGEMSG._serialized_end=26841
  _DEPSFOUNDDUPLICATEPACKAGE._serialized_start=26844
  _DEPSFOUNDDUPLICATEPACKAGE._serialized_end=27011
  _DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY._serialized_start=26958
  _DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY._serialized_end=27011
  _DEPSFOUNDDUPLICATEPACKAGEMSG._serialized_start=27013
  _DEPSFOUNDDUPLICATEPACKAGEMSG._serialized_end=27135
  _DEPSVERSIONMISSING._serialized_start=27137
  _DEPSVERSIONMISSING._serialized_end=27173
  _DEPSVERSIONMISSINGMSG._serialized_start=27175
  _DEPSVERSIONMISSINGMSG._serialized_end=27283
  _DEPSSCRUBBEDPACKAGENAME._serialized_start=27285
  _DEPSSCRUBBEDPACKAGENAME._serialized_end=27332
  _DEPSSCRUBBEDPACKAGENAMEMSG._serialized_start=27334
  _DEPSSCRUBBEDPACKAGENAMEMSG._serialized_end=27452
  _RUNNINGOPERATIONCAUGHTERROR._serialized_start=27454
  _RUNNINGOPERATIONCAUGHTERROR._serialized_end=27496
  _RUNNINGOPERATIONCAUGHTERRORMSG._serialized_start=27498
  _RUNNINGOPERATIONCAUGHTERRORMSG._serialized_end=27624
  _COMPILECOMPLETE._serialized_start=27626
  _COMPILECOMPLETE._serialized_end=27643
  _COMPILECOMPLETEMSG._serialized_start=27645
  _COMPILECOMPLETEMSG._serialized_end=27747
  _FRESHNESSCHECKCOMPLETE._serialized_start=27749
  _FRESHNESSCHECKCOMPLETE._serialized_end=27773
  _FRESHNESSCHECKCOMPLETEMSG._serialized_start=27775
  _FRESHNESSCHECKCOMPLETEMSG._serialized_end=27891
  _SEEDHEADER._serialized_start=27893
  _SEEDHEADER._serialized_end=27921
  _SEEDHEADERMSG._serialized_start=27923
  _SEEDHEADERMSG._serialized_end=28015
  _SQLRUNNEREXCEPTION._serialized_start=28017
  _SQLRUNNEREXCEPTION._serialized_end=28110
  _SQLRUNNEREXCEPTIONMSG._serialized_start=28112
  _SQLRUNNEREXCEPTIONMSG._serialized_end=28220
  _LOGTESTRESULT._serialized_start=28223
  _LOGTESTRESULT._serialized_end=28391
  _LOGTESTRESULTMSG._serialized_start=28393
  _LOGTESTRESULTMSG._serialized_end=28491
  _LOGSTARTLINE._serialized_start=28493
  _LOGSTARTLINE._serialized_end=28600
  _LOGSTARTLINEMSG._serialized_start=28602
  _LOGSTARTLINEMSG._serialized_end=28698
  _LOGMODELRESULT._serialized_start=28701
  _LOGMODELRESULT._serialized_end=28850
  _LOGMODELRESULTMSG._serialized_start=28852
  _LOGMODELRESULTMSG._serialized_end=28952
  _LOGSNAPSHOTRESULT._serialized_start=28955
  _LOGSNAPSHOTRESULT._serialized_end=29229
  _LOGSNAPSHOTRESULT_CFGENTRY._serialized_start=29187
  _LOGSNAPSHOTRESULT_CFGENTRY._serialized_end=29229
  _LOGSNAPSHOTRESULTMSG._serialized_start=29231
  _LOGSNAPSHOTRESULTMSG._serialized_end=29337
  _LOGSEEDRESULT._serialized_start=29340
  _LOGSEEDRESULT._serialized_end=29525
  _LOGSEEDRESULTMSG._serialized_start=29527
  _LOGSEEDRESULTMSG._serialized_end=29625
  _LOGFRESHNESSRESULT._serialized_start=29628
  _LOGFRESHNESSRESULT._serialized_end=29801
  _LOGFRESHNESSRESULTMSG._serialized_start=29803
  _LOGFRESHNESSRESULTMSG._serialized_end=29911
  _LOGCANCELLINE._serialized_start=29913
  _LOGCANCELLINE._serialized_end=29947
  _LOGCANCELLINEMSG._serialized_start=29949
  _LOGCANCELLINEMSG._serialized_end=30047
  _DEFAULTSELECTOR._serialized_start=30049
  _DEFAULTSELECTOR._serialized_end=30080
  _DEFAULTSELECTORMSG._serialized_start=30082
  _DEFAULTSELECTORMSG._serialized_end=30184
  _NODESTART._serialized_start=30186
  _NODESTART._serialized_end=30239
  _NODESTARTMSG._serialized_start=30241
  _NODESTARTMSG._serialized_end=30331
  _NODEFINISHED._serialized_start=30333
  _NODEFINISHED._serialized_end=30436
  _NODEFINISHEDMSG._serialized_start=30438
  _NODEFINISHEDMSG._serialized_end=30534
  _QUERYCANCELATIONUNSUPPORTED._serialized_start=30536
  _QUERYCANCELATIONUNSUPPORTED._serialized_end=30579
  _QUERYCANCELATIONUNSUPPORTEDMSG._serialized_start=30581
  _QUERYCANCELATIONUNSUPPORTEDMSG._serialized_end=30707
  _CONCURRENCYLINE._serialized_start=30709
  _CONCURRENCYLINE._serialized_end=30788
  _CONCURRENCYLINEMSG._serialized_start=30790
  _CONCURRENCYLINEMSG._serialized_end=30892
  _WRITINGINJECTEDSQLFORNODE._serialized_start=30894
  _WRITINGINJECTEDSQLFORNODE._serialized_end=30963
  _WRITINGINJECTEDSQLFORNODEMSG._serialized_start=30965
  _WRITINGINJECTEDSQLFORNODEMSG._serialized_end=31087
  _NODECOMPILING._serialized_start=31089
  _NODECOMPILING._serialized_end=31146
  _NODECOMPILINGMSG._serialized_start=31148
  _NODECOMPILINGMSG._serialized_end=31246
  _NODEEXECUTING._serialized_start=31248
  _NODEEXECUTING._serialized_end=31305
  _NODEEXECUTINGMSG._serialized_start=31307
  _NODEEXECUTINGMSG._serialized_end=31405
  _LOGHOOKSTARTLINE._serialized_start=31407
  _LOGHOOKSTARTLINE._serialized_end=31516
  _LOGHOOKSTARTLINEMSG._serialized_start=31518
  _LOGHOOKSTARTLINEMSG._serialized_end=31622
  _LOGHOOKENDLINE._serialized_start=31625
  _LOGHOOKENDLINE._serialized_end=31772
  _LOGHOOKENDLINEMSG._serialized_start=31774
  _LOGHOOKENDLINEMSG._serialized_end=31874
  _SKIPPINGDETAILS._serialized_start=31877
  _SKIPPINGDETAILS._serialized_end=32024
  _SKIPPINGDETAILSMSG._serialized_start=32026
  _SKIPPINGDETAILSMSG._serialized_end=32128
  _NOTHINGTODO._serialized_start=32130
  _NOTHINGTODO._serialized_end=32143
  _NOTHINGTODOMSG._serialized_start=32145
  _NOTHINGTODOMSG._serialized_end=32239
  _RUNNINGOPERATIONUNCAUGHTERROR._serialized_start=32241
  _RUNNINGOPERATIONUNCAUGHTERROR._serialized_end=32285
  _RUNNINGOPERATIONUNCAUGHTERRORMSG._serialized_start=32288
  _RUNNINGOPERATIONUNCAUGHTERRORMSG._serialized_end=32418
  _ENDRUNRESULT._serialized_start=32421
  _ENDRUNRESULT._serialized_end=32568
  _ENDRUNRESULTMSG._serialized_start=32570
  _ENDRUNRESULTMSG._serialized_end=32666
  _NONODESSELECTED._serialized_start=32668
  _NONODESSELECTED._serialized_end=32685
  _NONODESSELECTEDMSG._serialized_start=32687
  _NONODESSELECTEDMSG._serialized_end=32789
  _COMMANDCOMPLETED._serialized_start=32791
  _COMMANDCOMPLETED._serialized_end=32910
  _COMMANDCOMPLETEDMSG._serialized_start=32912
  _COMMANDCOMPLETEDMSG._serialized_end=33016
  _SHOWNODE._serialized_start=33018
  _SHOWNODE._serialized_end=33125
  _SHOWNODEMSG._serialized_start=33127
  _SHOWNODEMSG._serialized_end=33215
  _COMPILEDNODE._serialized_start=33217
  _COMPILEDNODE._serialized_end=33329
  _COMPILEDNODEMSG._serialized_start=33331
  _COMPILEDNODEMSG._serialized_end=33427
  _CATCHABLEEXCEPTIONONRUN._serialized_start=33429
  _CATCHABLEEXCEPTIONONRUN._serialized_end=33527
  _CATCHABLEEXCEPTIONONRUNMSG._serialized_start=33529
  _CATCHABLEEXCEPTIONONRUNMSG._serialized_end=33647
  _INTERNALERRORONRUN._serialized_start=33649
  _INTERNALERRORONRUN._serialized_end=33744
  _INTERNALERRORONRUNMSG._serialized_start=33746
  _INTERNALERRORONRUNMSG._serialized_end=33854
  _GENERICEXCEPTIONONRUN._serialized_start=33856
  _GENERICEXCEPTIONONRUN._serialized_end=33973
  _GENERICEXCEPTIONONRUNMSG._serialized_start=33975
  _GENERICEXCEPTIONONRUNMSG._serialized_end=34089
  _NODECONNECTIONRELEASEERROR._serialized_start=34091
  _NODECONNECTIONRELEASEERROR._serialized_end=34169
  _NODECONNECTIONRELEASEERRORMSG._serialized_start=34171
  _NODECONNECTIONRELEASEERRORMSG._serialized_end=34295
  _FOUNDSTATS._serialized_start=34297
  _FOUNDSTATS._serialized_end=34328
  _FOUNDSTATSMSG._serialized_start=34330
  _FOUNDSTATSMSG._serialized_end=34422
  _MAINKEYBOARDINTERRUPT._serialized_start=34424
  _MAINKEYBOARDINTERRUPT._serialized_end=34447
  _MAINKEYBOARDINTERRUPTMSG._serialized_start=34449
  _MAINKEYBOARDINTERRUPTMSG._serialized_end=34563
  _MAINENCOUNTEREDERROR._serialized_start=34565
  _MAINENCOUNTEREDERROR._serialized_end=34600
  _MAINENCOUNTEREDERRORMSG._serialized_start=34602
  _MAINENCOUNTEREDERRORMSG._serialized_end=34714
  _MAINSTACKTRACE._serialized_start=34716
  _MAINSTACKTRACE._serialized_end=34753
  _MAINSTACKTRACEMSG._serialized_start=34755
  _MAINSTACKTRACEMSG._serialized_end=34855
  _SYSTEMCOULDNOTWRITE._serialized_start=34857
  _SYSTEMCOULDNOTWRITE._serialized_end=34921
  _SYSTEMCOULDNOTWRITEMSG._serialized_start=34923
  _SYSTEMCOULDNOTWRITEMSG._serialized_end=35033
  _SYSTEMEXECUTINGCMD._serialized_start=35035
  _SYSTEMEXECUTINGCMD._serialized_end=35068
  _SYSTEMEXECUTINGCMDMSG._serialized_start=35070
  _SYSTEMEXECUTINGCMDMSG._serialized_end=35178
  _SYSTEMSTDOUT._serialized_start=35180
  _SYSTEMSTDOUT._serialized_end=35208
  _SYSTEMSTDOUTMSG._serialized_start=35210
  _SYSTEMSTDOUTMSG._serialized_end=35306
  _SYSTEMSTDERR._serialized_start=35308
  _SYSTEMSTDERR._serialized_end=35336
  _SYSTEMSTDERRMSG._serialized_start=35338
  _SYSTEMSTDERRMSG._serialized_end=35434
  _SYSTEMREPORTRETURNCODE._serialized_start=35436
  _SYSTEMREPORTRETURNCODE._serialized_end=35480
  _SYSTEMREPORTRETURNCODEMSG._serialized_start=35482
  _SYSTEMREPORTRETURNCODEMSG._serialized_end=35598
  _TIMINGINFOCOLLECTED._serialized_start=35600
  _TIMINGINFOCOLLECTED._serialized_end=35712
  _TIMINGINFOCOLLECTEDMSG._serialized_start=35714
  _TIMINGINFOCOLLECTEDMSG._serialized_end=35824
  _LOGDEBUGSTACKTRACE._serialized_start=35826
  _LOGDEBUGSTACKTRACE._serialized_end=35864
  _LOGDEBUGSTACKTRACEMSG._serialized_start=35866
  _LOGDEBUGSTACKTRACEMSG._serialized_end=35974
  _CHECKCLEANPATH._serialized_start=35976
  _CHECKCLEANPATH._serialized_end=36006
  _CHECKCLEANPATHMSG._serialized_start=36008
  _CHECKCLEANPATHMSG._serialized_end=36108
  _CONFIRMCLEANPATH._serialized_start=36110
  _CONFIRMCLEANPATH._serialized_end=36142
  _CONFIRMCLEANPATHMSG._serialized_start=36144
  _CONFIRMCLEANPATHMSG._serialized_end=36248
  _PROTECTEDCLEANPATH._serialized_start=36250
  _PROTECTEDCLEANPATH._serialized_end=36284
  _PROTECTEDCLEANPATHMSG._serialized_start=36286
  _PROTECTEDCLEANPATHMSG._serialized_end=36394
  _FINISHEDCLEANPATHS._serialized_start=36396
  _FINISHEDCLEANPATHS._serialized_end=36416
  _FINISHEDCLEANPATHSMSG._serialized_start=36418
  _FINISHEDCLEANPATHSMSG._serialized_end=36526
  _OPENCOMMAND._serialized_start=36528
  _OPENCOMMAND._serialized_end=36581
  _OPENCOMMANDMSG._serialized_start=36583
  _OPENCOMMANDMSG._serialized_end=36677
  _FORMATTING._serialized_start=36679
  _FORMATTING._serialized_end=36704
  _FORMATTINGMSG._serialized_start=36706
  _FORMATTINGMSG._serialized_end=36798
  _SERVINGDOCSPORT._serialized_start=36800
  _SERVINGDOCSPORT._serialized_end=36848
  _SERVINGDOCSPORTMSG._serialized_start=36850
  _SERVINGDOCSPORTMSG._serialized_end=36952
  _SERVINGDOCSACCESSINFO._serialized_start=36954
  _SERVINGDOCSACCESSINFO._serialized_end=36991
  _SERVINGDOCSACCESSINFOMSG._serialized_start=36993
  _SERVINGDOCSACCESSINFOMSG._serialized_end=37107
  _SERVINGDOCSEXITINFO._serialized_start=37109
  _SERVINGDOCSEXITINFO._serialized_end=37130
  _SERVINGDOCSEXITINFOMSG._serialized_start=37132
  _SERVINGDOCSEXITINFOMSG._serialized_end=37242
  _RUNRESULTWARNING._serialized_start=37244
  _RUNRESULTWARNING._serialized_end=37318
  _RUNRESULTWARNINGMSG._serialized_start=37320
  _RUNRESULTWARNINGMSG._serialized_end=37424
  _RUNRESULTFAILURE._serialized_start=37426
  _RUNRESULTFAILURE._serialized_end=37500
  _RUNRESULTFAILUREMSG._serialized_start=37502
  _RUNRESULTFAILUREMSG._serialized_end=37606
  _STATSLINE._serialized_start=37608
  _STATSLINE._serialized_end=37715
  _STATSLINE_STATSENTRY._serialized_start=37671
  _STATSLINE_STATSENTRY._serialized_end=37715
  _STATSLINEMSG._serialized_start=37717
  _STATSLINEMSG._serialized_end=37807
  _RUNRESULTERROR._serialized_start=37809
  _RUNRESULTERROR._serialized_end=37838
  _RUNRESULTERRORMSG._serialized_start=37840
  _RUNRESULTERRORMSG._serialized_end=37940
  _RUNRESULTERRORNOMESSAGE._serialized_start=37942
  _RUNRESULTERRORNOMESSAGE._serialized_end=37983
  _RUNRESULTERRORNOMESSAGEMSG._serialized_start=37985
  _RUNRESULTERRORNOMESSAGEMSG._serialized_end=38103
  _SQLCOMPILEDPATH._serialized_start=38105
  _SQLCOMPILEDPATH._serialized_end=38136
  _SQLCOMPILEDPATHMSG._serialized_start=38138
  _SQLCOMPILEDPATHMSG._serialized_end=38240
  _CHECKNODETESTFAILURE._serialized_start=38242
  _CHECKNODETESTFAILURE._serialized_end=38287
  _CHECKNODETESTFAILUREMSG._serialized_start=38289
  _CHECKNODETESTFAILUREMSG._serialized_end=38401
  _ENDOFRUNSUMMARY._serialized_start=38403
  _ENDOFRUNSUMMARY._serialized_end=38490
  _ENDOFRUNSUMMARYMSG._serialized_start=38492
  _ENDOFRUNSUMMARYMSG._serialized_end=38594
  _LOGSKIPBECAUSEERROR._serialized_start=38596
  _LOGSKIPBECAUSEERROR._serialized_end=38681
  _LOGSKIPBECAUSEERRORMSG._serialized_start=38683
  _LOGSKIPBECAUSEERRORMSG._serialized_end=38793
  _ENSUREGITINSTALLED._serialized_start=38795
  _ENSUREGITINSTALLED._serialized_end=38815
  _ENSUREGITINSTALLEDMSG._serialized_start=38817
  _ENSUREGITINSTALLEDMSG._serialized_end=38925
  _DEPSCREATINGLOCALSYMLINK._serialized_start=38927
  _DEPSCREATINGLOCALSYMLINK._serialized_end=38953
  _DEPSCREATINGLOCALSYMLINKMSG._serialized_start=38955
  _DEPSCREATINGLOCALSYMLINKMSG._serialized_end=39075
  _DEPSSYMLINKNOTAVAILABLE._serialized_start=39077
  _DEPSSYMLINKNOTAVAILABLE._serialized_end=39102
  _DEPSSYMLINKNOTAVAILABLEMSG._serialized_start=39104
  _DEPSSYMLINKNOTAVAILABLEMSG._serialized_end=39222
  _DISABLETRACKING._serialized_start=39224
  _DISABLETRACKING._serialized_end=39241
  _DISABLETRACKINGMSG._serialized_start=39243
  _DISABLETRACKINGMSG._serialized_end=39345
  _SENDINGEVENT._serialized_start=39347
  _SENDINGEVENT._serialized_end=39377
  _SENDINGEVENTMSG._serialized_start=39379
  _SENDINGEVENTMSG._serialized_end=39475
  _SENDEVENTFAILURE._serialized_start=39477
  _SENDEVENTFAILURE._serialized_end=39495
  _SENDEVENTFAILUREMSG._serialized_start=39497
  _SENDEVENTFAILUREMSG._serialized_end=39601
  _FLUSHEVENTS._serialized_start=39603
  _FLUSHEVENTS._serialized_end=39616
  _FLUSHEVENTSMSG._serialized_start=39618
  _FLUSHEVENTSMSG._serialized_end=39712
  _FLUSHEVENTSFAILURE._serialized_start=39714
  _FLUSHEVENTSFAILURE._serialized_end=39734
  _FLUSHEVENTSFAILUREMSG._serialized_start=39736
  _FLUSHEVENTSFAILUREMSG._serialized_end=39844
  _TRACKINGINITIALIZEFAILURE._serialized_start=39846
  _TRACKINGINITIALIZEFAILURE._serialized_end=39891
  _TRACKINGINITIALIZEFAILUREMSG._serialized_start=39893
  _TRACKINGINITIALIZEFAILUREMSG._serialized_end=40015
  _RUNRESULTWARNINGMESSAGE._serialized_start=40017
  _RUNRESULTWARNINGMESSAGE._serialized_end=40055
  _RUNRESULTWARNINGMESSAGEMSG._serialized_start=40057
  _RUNRESULTWARNINGMESSAGEMSG._serialized_end=40175
  _DEBUGCMDOUT._serialized_start=40177
  _DEBUGCMDOUT._serialized_end=40203
  _DEBUGCMDOUTMSG._serialized_start=40205
  _DEBUGCMDOUTMSG._serialized_end=40299
  _DEBUGCMDRESULT._serialized_start=40301
  _DEBUGCMDRESULT._serialized_end=40330
  _DEBUGCMDRESULTMSG._serialized_start=40332
  _DEBUGCMDRESULTMSG._serialized_end=40432
  _LISTCMDOUT._serialized_start=40434
  _LISTCMDOUT._serialized_end=40459
  _LISTCMDOUTMSG._serialized_start=40461
  _LISTCMDOUTMSG._serialized_end=40553
  _NOTE._serialized_start=40555
  _NOTE._serialized_end=40574
  _NOTEMSG._serialized_start=40576
  _NOTEMSG._serialized_end=40656
  _RESOURCEREPORT._serialized_start=40659
  _RESOURCEREPORT._serialized_end=40895
  _RESOURCEREPORTMSG._serialized_start=40897
  _RESOURCEREPORTMSG._serialized_end=40997
# @@protoc_insertion_point(module_scope)
